"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeRegionAutoscalerXAutoscalingPolicyXCpuUtilization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREDICTIVE_METHOD_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    predictive_method: builtins.str
    target: builtins.float
    def __init__(
        self,
        *,
        predictive_method: builtins.str = ...,
        target: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["predictive_method", b"predictive_method", "target", b"target"]) -> None: ...

global___ComputeRegionAutoscalerXAutoscalingPolicyXCpuUtilization = ComputeRegionAutoscalerXAutoscalingPolicyXCpuUtilization

@typing_extensions.final
class ComputeRegionAutoscalerXAutoscalingPolicyXLoadBalancingUtilization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_FIELD_NUMBER: builtins.int
    target: builtins.float
    def __init__(
        self,
        *,
        target: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target", b"target"]) -> None: ...

global___ComputeRegionAutoscalerXAutoscalingPolicyXLoadBalancingUtilization = ComputeRegionAutoscalerXAutoscalingPolicyXLoadBalancingUtilization

@typing_extensions.final
class ComputeRegionAutoscalerXAutoscalingPolicyXMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    target: builtins.float
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        target: builtins.float = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "target", b"target", "type", b"type"]) -> None: ...

global___ComputeRegionAutoscalerXAutoscalingPolicyXMetric = ComputeRegionAutoscalerXAutoscalingPolicyXMetric

@typing_extensions.final
class ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIXED_FIELD_NUMBER: builtins.int
    PERCENT_FIELD_NUMBER: builtins.int
    fixed: builtins.float
    percent: builtins.float
    def __init__(
        self,
        *,
        fixed: builtins.float = ...,
        percent: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed", b"fixed", "percent", b"percent"]) -> None: ...

global___ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas = ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas

@typing_extensions.final
class ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_WINDOW_SEC_FIELD_NUMBER: builtins.int
    MAX_SCALED_IN_REPLICAS_FIELD_NUMBER: builtins.int
    time_window_sec: builtins.float
    @property
    def max_scaled_in_replicas(self) -> global___ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas: ...
    def __init__(
        self,
        *,
        time_window_sec: builtins.float = ...,
        max_scaled_in_replicas: global___ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_scaled_in_replicas", b"max_scaled_in_replicas"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_scaled_in_replicas", b"max_scaled_in_replicas", "time_window_sec", b"time_window_sec"]) -> None: ...

global___ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControl = ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControl

@typing_extensions.final
class ComputeRegionAutoscalerXAutoscalingPolicyXScalingSchedules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DURATION_SEC_FIELD_NUMBER: builtins.int
    MIN_REQUIRED_REPLICAS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    duration_sec: builtins.float
    min_required_replicas: builtins.float
    name: builtins.str
    schedule: builtins.str
    time_zone: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        duration_sec: builtins.float = ...,
        min_required_replicas: builtins.float = ...,
        name: builtins.str = ...,
        schedule: builtins.str = ...,
        time_zone: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "duration_sec", b"duration_sec", "min_required_replicas", b"min_required_replicas", "name", b"name", "schedule", b"schedule", "time_zone", b"time_zone"]) -> None: ...

global___ComputeRegionAutoscalerXAutoscalingPolicyXScalingSchedules = ComputeRegionAutoscalerXAutoscalingPolicyXScalingSchedules

@typing_extensions.final
class ComputeRegionAutoscalerXAutoscalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COOLDOWN_PERIOD_FIELD_NUMBER: builtins.int
    MAX_REPLICAS_FIELD_NUMBER: builtins.int
    MIN_REPLICAS_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    CPU_UTILIZATION_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_UTILIZATION_FIELD_NUMBER: builtins.int
    METRIC_FIELD_NUMBER: builtins.int
    SCALE_IN_CONTROL_FIELD_NUMBER: builtins.int
    SCALING_SCHEDULES_FIELD_NUMBER: builtins.int
    cooldown_period: builtins.float
    max_replicas: builtins.float
    min_replicas: builtins.float
    mode: builtins.str
    @property
    def cpu_utilization(self) -> global___ComputeRegionAutoscalerXAutoscalingPolicyXCpuUtilization: ...
    @property
    def load_balancing_utilization(self) -> global___ComputeRegionAutoscalerXAutoscalingPolicyXLoadBalancingUtilization: ...
    @property
    def metric(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionAutoscalerXAutoscalingPolicyXMetric]: ...
    @property
    def scale_in_control(self) -> global___ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControl: ...
    @property
    def scaling_schedules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionAutoscalerXAutoscalingPolicyXScalingSchedules]: ...
    def __init__(
        self,
        *,
        cooldown_period: builtins.float = ...,
        max_replicas: builtins.float = ...,
        min_replicas: builtins.float = ...,
        mode: builtins.str = ...,
        cpu_utilization: global___ComputeRegionAutoscalerXAutoscalingPolicyXCpuUtilization | None = ...,
        load_balancing_utilization: global___ComputeRegionAutoscalerXAutoscalingPolicyXLoadBalancingUtilization | None = ...,
        metric: collections.abc.Iterable[global___ComputeRegionAutoscalerXAutoscalingPolicyXMetric] | None = ...,
        scale_in_control: global___ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControl | None = ...,
        scaling_schedules: collections.abc.Iterable[global___ComputeRegionAutoscalerXAutoscalingPolicyXScalingSchedules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cpu_utilization", b"cpu_utilization", "load_balancing_utilization", b"load_balancing_utilization", "scale_in_control", b"scale_in_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cooldown_period", b"cooldown_period", "cpu_utilization", b"cpu_utilization", "load_balancing_utilization", b"load_balancing_utilization", "max_replicas", b"max_replicas", "metric", b"metric", "min_replicas", b"min_replicas", "mode", b"mode", "scale_in_control", b"scale_in_control", "scaling_schedules", b"scaling_schedules"]) -> None: ...

global___ComputeRegionAutoscalerXAutoscalingPolicy = ComputeRegionAutoscalerXAutoscalingPolicy

@typing_extensions.final
class ComputeRegionAutoscalerXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRegionAutoscalerXTimeouts = ComputeRegionAutoscalerXTimeouts

@typing_extensions.final
class ComputeRegionAutoscaler(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    AUTOSCALING_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    target: builtins.str
    @property
    def autoscaling_policy(self) -> global___ComputeRegionAutoscalerXAutoscalingPolicy: ...
    @property
    def timeouts(self) -> global___ComputeRegionAutoscalerXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        target: builtins.str = ...,
        autoscaling_policy: global___ComputeRegionAutoscalerXAutoscalingPolicy | None = ...,
        timeouts: global___ComputeRegionAutoscalerXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling_policy", b"autoscaling_policy", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling_policy", b"autoscaling_policy", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "target", b"target", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRegionAutoscaler = ComputeRegionAutoscaler

@typing_extensions.final
class ComputeRegionBackendServiceXBackend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BALANCING_MODE_FIELD_NUMBER: builtins.int
    CAPACITY_SCALER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FAILOVER_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_PER_ENDPOINT_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_PER_INSTANCE_FIELD_NUMBER: builtins.int
    MAX_RATE_FIELD_NUMBER: builtins.int
    MAX_RATE_PER_ENDPOINT_FIELD_NUMBER: builtins.int
    MAX_RATE_PER_INSTANCE_FIELD_NUMBER: builtins.int
    MAX_UTILIZATION_FIELD_NUMBER: builtins.int
    balancing_mode: builtins.str
    capacity_scaler: builtins.float
    description: builtins.str
    failover: builtins.bool
    group: builtins.str
    max_connections: builtins.float
    max_connections_per_endpoint: builtins.float
    max_connections_per_instance: builtins.float
    max_rate: builtins.float
    max_rate_per_endpoint: builtins.float
    max_rate_per_instance: builtins.float
    max_utilization: builtins.float
    def __init__(
        self,
        *,
        balancing_mode: builtins.str = ...,
        capacity_scaler: builtins.float = ...,
        description: builtins.str = ...,
        failover: builtins.bool = ...,
        group: builtins.str = ...,
        max_connections: builtins.float = ...,
        max_connections_per_endpoint: builtins.float = ...,
        max_connections_per_instance: builtins.float = ...,
        max_rate: builtins.float = ...,
        max_rate_per_endpoint: builtins.float = ...,
        max_rate_per_instance: builtins.float = ...,
        max_utilization: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["balancing_mode", b"balancing_mode", "capacity_scaler", b"capacity_scaler", "description", b"description", "failover", b"failover", "group", b"group", "max_connections", b"max_connections", "max_connections_per_endpoint", b"max_connections_per_endpoint", "max_connections_per_instance", b"max_connections_per_instance", "max_rate", b"max_rate", "max_rate_per_endpoint", b"max_rate_per_endpoint", "max_rate_per_instance", b"max_rate_per_instance", "max_utilization", b"max_utilization"]) -> None: ...

global___ComputeRegionBackendServiceXBackend = ComputeRegionBackendServiceXBackend

@typing_extensions.final
class ComputeRegionBackendServiceXCdnPolicyXCacheKeyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_HOST_FIELD_NUMBER: builtins.int
    INCLUDE_NAMED_COOKIES_FIELD_NUMBER: builtins.int
    INCLUDE_PROTOCOL_FIELD_NUMBER: builtins.int
    INCLUDE_QUERY_STRING_FIELD_NUMBER: builtins.int
    QUERY_STRING_BLACKLIST_FIELD_NUMBER: builtins.int
    QUERY_STRING_WHITELIST_FIELD_NUMBER: builtins.int
    include_host: builtins.bool
    @property
    def include_named_cookies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    include_protocol: builtins.bool
    include_query_string: builtins.bool
    @property
    def query_string_blacklist(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def query_string_whitelist(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        include_host: builtins.bool = ...,
        include_named_cookies: collections.abc.Iterable[builtins.str] | None = ...,
        include_protocol: builtins.bool = ...,
        include_query_string: builtins.bool = ...,
        query_string_blacklist: collections.abc.Iterable[builtins.str] | None = ...,
        query_string_whitelist: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_host", b"include_host", "include_named_cookies", b"include_named_cookies", "include_protocol", b"include_protocol", "include_query_string", b"include_query_string", "query_string_blacklist", b"query_string_blacklist", "query_string_whitelist", b"query_string_whitelist"]) -> None: ...

global___ComputeRegionBackendServiceXCdnPolicyXCacheKeyPolicy = ComputeRegionBackendServiceXCdnPolicyXCacheKeyPolicy

@typing_extensions.final
class ComputeRegionBackendServiceXCdnPolicyXNegativeCachingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    code: builtins.float
    def __init__(
        self,
        *,
        code: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code"]) -> None: ...

global___ComputeRegionBackendServiceXCdnPolicyXNegativeCachingPolicy = ComputeRegionBackendServiceXCdnPolicyXNegativeCachingPolicy

@typing_extensions.final
class ComputeRegionBackendServiceXCdnPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHE_MODE_FIELD_NUMBER: builtins.int
    CLIENT_TTL_FIELD_NUMBER: builtins.int
    DEFAULT_TTL_FIELD_NUMBER: builtins.int
    MAX_TTL_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_FIELD_NUMBER: builtins.int
    SERVE_WHILE_STALE_FIELD_NUMBER: builtins.int
    SIGNED_URL_CACHE_MAX_AGE_SEC_FIELD_NUMBER: builtins.int
    CACHE_KEY_POLICY_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_POLICY_FIELD_NUMBER: builtins.int
    cache_mode: builtins.str
    client_ttl: builtins.float
    default_ttl: builtins.float
    max_ttl: builtins.float
    negative_caching: builtins.bool
    serve_while_stale: builtins.float
    signed_url_cache_max_age_sec: builtins.float
    @property
    def cache_key_policy(self) -> global___ComputeRegionBackendServiceXCdnPolicyXCacheKeyPolicy: ...
    @property
    def negative_caching_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionBackendServiceXCdnPolicyXNegativeCachingPolicy]: ...
    def __init__(
        self,
        *,
        cache_mode: builtins.str = ...,
        client_ttl: builtins.float = ...,
        default_ttl: builtins.float = ...,
        max_ttl: builtins.float = ...,
        negative_caching: builtins.bool = ...,
        serve_while_stale: builtins.float = ...,
        signed_url_cache_max_age_sec: builtins.float = ...,
        cache_key_policy: global___ComputeRegionBackendServiceXCdnPolicyXCacheKeyPolicy | None = ...,
        negative_caching_policy: collections.abc.Iterable[global___ComputeRegionBackendServiceXCdnPolicyXNegativeCachingPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cache_key_policy", b"cache_key_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_key_policy", b"cache_key_policy", "cache_mode", b"cache_mode", "client_ttl", b"client_ttl", "default_ttl", b"default_ttl", "max_ttl", b"max_ttl", "negative_caching", b"negative_caching", "negative_caching_policy", b"negative_caching_policy", "serve_while_stale", b"serve_while_stale", "signed_url_cache_max_age_sec", b"signed_url_cache_max_age_sec"]) -> None: ...

global___ComputeRegionBackendServiceXCdnPolicy = ComputeRegionBackendServiceXCdnPolicy

@typing_extensions.final
class ComputeRegionBackendServiceXCircuitBreakers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_PENDING_REQUESTS_FIELD_NUMBER: builtins.int
    MAX_REQUESTS_FIELD_NUMBER: builtins.int
    MAX_REQUESTS_PER_CONNECTION_FIELD_NUMBER: builtins.int
    MAX_RETRIES_FIELD_NUMBER: builtins.int
    max_connections: builtins.float
    max_pending_requests: builtins.float
    max_requests: builtins.float
    max_requests_per_connection: builtins.float
    max_retries: builtins.float
    def __init__(
        self,
        *,
        max_connections: builtins.float = ...,
        max_pending_requests: builtins.float = ...,
        max_requests: builtins.float = ...,
        max_requests_per_connection: builtins.float = ...,
        max_retries: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_connections", b"max_connections", "max_pending_requests", b"max_pending_requests", "max_requests", b"max_requests", "max_requests_per_connection", b"max_requests_per_connection", "max_retries", b"max_retries"]) -> None: ...

global___ComputeRegionBackendServiceXCircuitBreakers = ComputeRegionBackendServiceXCircuitBreakers

@typing_extensions.final
class ComputeRegionBackendServiceXConsistentHashXHttpCookieXTtl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeRegionBackendServiceXConsistentHashXHttpCookieXTtl = ComputeRegionBackendServiceXConsistentHashXHttpCookieXTtl

@typing_extensions.final
class ComputeRegionBackendServiceXConsistentHashXHttpCookie(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    @property
    def ttl(self) -> global___ComputeRegionBackendServiceXConsistentHashXHttpCookieXTtl: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
        ttl: global___ComputeRegionBackendServiceXConsistentHashXHttpCookieXTtl | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ttl", b"ttl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "path", b"path", "ttl", b"ttl"]) -> None: ...

global___ComputeRegionBackendServiceXConsistentHashXHttpCookie = ComputeRegionBackendServiceXConsistentHashXHttpCookie

@typing_extensions.final
class ComputeRegionBackendServiceXConsistentHash(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_HEADER_NAME_FIELD_NUMBER: builtins.int
    MINIMUM_RING_SIZE_FIELD_NUMBER: builtins.int
    HTTP_COOKIE_FIELD_NUMBER: builtins.int
    http_header_name: builtins.str
    minimum_ring_size: builtins.float
    @property
    def http_cookie(self) -> global___ComputeRegionBackendServiceXConsistentHashXHttpCookie: ...
    def __init__(
        self,
        *,
        http_header_name: builtins.str = ...,
        minimum_ring_size: builtins.float = ...,
        http_cookie: global___ComputeRegionBackendServiceXConsistentHashXHttpCookie | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["http_cookie", b"http_cookie"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_cookie", b"http_cookie", "http_header_name", b"http_header_name", "minimum_ring_size", b"minimum_ring_size"]) -> None: ...

global___ComputeRegionBackendServiceXConsistentHash = ComputeRegionBackendServiceXConsistentHash

@typing_extensions.final
class ComputeRegionBackendServiceXFailoverPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLE_CONNECTION_DRAIN_ON_FAILOVER_FIELD_NUMBER: builtins.int
    DROP_TRAFFIC_IF_UNHEALTHY_FIELD_NUMBER: builtins.int
    FAILOVER_RATIO_FIELD_NUMBER: builtins.int
    disable_connection_drain_on_failover: builtins.bool
    drop_traffic_if_unhealthy: builtins.bool
    failover_ratio: builtins.float
    def __init__(
        self,
        *,
        disable_connection_drain_on_failover: builtins.bool = ...,
        drop_traffic_if_unhealthy: builtins.bool = ...,
        failover_ratio: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_connection_drain_on_failover", b"disable_connection_drain_on_failover", "drop_traffic_if_unhealthy", b"drop_traffic_if_unhealthy", "failover_ratio", b"failover_ratio"]) -> None: ...

global___ComputeRegionBackendServiceXFailoverPolicy = ComputeRegionBackendServiceXFailoverPolicy

@typing_extensions.final
class ComputeRegionBackendServiceXIap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH2_CLIENT_ID_FIELD_NUMBER: builtins.int
    OAUTH2_CLIENT_SECRET_FIELD_NUMBER: builtins.int
    OAUTH2_CLIENT_SECRET_SHA256_FIELD_NUMBER: builtins.int
    oauth2_client_id: builtins.str
    oauth2_client_secret: builtins.str
    oauth2_client_secret_sha256: builtins.str
    def __init__(
        self,
        *,
        oauth2_client_id: builtins.str = ...,
        oauth2_client_secret: builtins.str = ...,
        oauth2_client_secret_sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oauth2_client_id", b"oauth2_client_id", "oauth2_client_secret", b"oauth2_client_secret", "oauth2_client_secret_sha256", b"oauth2_client_secret_sha256"]) -> None: ...

global___ComputeRegionBackendServiceXIap = ComputeRegionBackendServiceXIap

@typing_extensions.final
class ComputeRegionBackendServiceXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    SAMPLE_RATE_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    sample_rate: builtins.float
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        sample_rate: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable", "sample_rate", b"sample_rate"]) -> None: ...

global___ComputeRegionBackendServiceXLogConfig = ComputeRegionBackendServiceXLogConfig

@typing_extensions.final
class ComputeRegionBackendServiceXOutlierDetectionXBaseEjectionTime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeRegionBackendServiceXOutlierDetectionXBaseEjectionTime = ComputeRegionBackendServiceXOutlierDetectionXBaseEjectionTime

@typing_extensions.final
class ComputeRegionBackendServiceXOutlierDetectionXInterval(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeRegionBackendServiceXOutlierDetectionXInterval = ComputeRegionBackendServiceXOutlierDetectionXInterval

@typing_extensions.final
class ComputeRegionBackendServiceXOutlierDetection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSECUTIVE_ERRORS_FIELD_NUMBER: builtins.int
    CONSECUTIVE_GATEWAY_FAILURE_FIELD_NUMBER: builtins.int
    ENFORCING_CONSECUTIVE_ERRORS_FIELD_NUMBER: builtins.int
    ENFORCING_CONSECUTIVE_GATEWAY_FAILURE_FIELD_NUMBER: builtins.int
    ENFORCING_SUCCESS_RATE_FIELD_NUMBER: builtins.int
    MAX_EJECTION_PERCENT_FIELD_NUMBER: builtins.int
    SUCCESS_RATE_MINIMUM_HOSTS_FIELD_NUMBER: builtins.int
    SUCCESS_RATE_REQUEST_VOLUME_FIELD_NUMBER: builtins.int
    SUCCESS_RATE_STDEV_FACTOR_FIELD_NUMBER: builtins.int
    BASE_EJECTION_TIME_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    consecutive_errors: builtins.float
    consecutive_gateway_failure: builtins.float
    enforcing_consecutive_errors: builtins.float
    enforcing_consecutive_gateway_failure: builtins.float
    enforcing_success_rate: builtins.float
    max_ejection_percent: builtins.float
    success_rate_minimum_hosts: builtins.float
    success_rate_request_volume: builtins.float
    success_rate_stdev_factor: builtins.float
    @property
    def base_ejection_time(self) -> global___ComputeRegionBackendServiceXOutlierDetectionXBaseEjectionTime: ...
    @property
    def interval(self) -> global___ComputeRegionBackendServiceXOutlierDetectionXInterval: ...
    def __init__(
        self,
        *,
        consecutive_errors: builtins.float = ...,
        consecutive_gateway_failure: builtins.float = ...,
        enforcing_consecutive_errors: builtins.float = ...,
        enforcing_consecutive_gateway_failure: builtins.float = ...,
        enforcing_success_rate: builtins.float = ...,
        max_ejection_percent: builtins.float = ...,
        success_rate_minimum_hosts: builtins.float = ...,
        success_rate_request_volume: builtins.float = ...,
        success_rate_stdev_factor: builtins.float = ...,
        base_ejection_time: global___ComputeRegionBackendServiceXOutlierDetectionXBaseEjectionTime | None = ...,
        interval: global___ComputeRegionBackendServiceXOutlierDetectionXInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_ejection_time", b"base_ejection_time", "interval", b"interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_ejection_time", b"base_ejection_time", "consecutive_errors", b"consecutive_errors", "consecutive_gateway_failure", b"consecutive_gateway_failure", "enforcing_consecutive_errors", b"enforcing_consecutive_errors", "enforcing_consecutive_gateway_failure", b"enforcing_consecutive_gateway_failure", "enforcing_success_rate", b"enforcing_success_rate", "interval", b"interval", "max_ejection_percent", b"max_ejection_percent", "success_rate_minimum_hosts", b"success_rate_minimum_hosts", "success_rate_request_volume", b"success_rate_request_volume", "success_rate_stdev_factor", b"success_rate_stdev_factor"]) -> None: ...

global___ComputeRegionBackendServiceXOutlierDetection = ComputeRegionBackendServiceXOutlierDetection

@typing_extensions.final
class ComputeRegionBackendServiceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRegionBackendServiceXTimeouts = ComputeRegionBackendServiceXTimeouts

@typing_extensions.final
class ComputeRegionBackendService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AFFINITY_COOKIE_TTL_SEC_FIELD_NUMBER: builtins.int
    CONNECTION_DRAINING_TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLE_CDN_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    HEALTH_CHECKS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_SCHEME_FIELD_NUMBER: builtins.int
    LOCALITY_LB_POLICY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_FIELD_NUMBER: builtins.int
    TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    BACKEND_FIELD_NUMBER: builtins.int
    CDN_POLICY_FIELD_NUMBER: builtins.int
    CIRCUIT_BREAKERS_FIELD_NUMBER: builtins.int
    CONSISTENT_HASH_FIELD_NUMBER: builtins.int
    FAILOVER_POLICY_FIELD_NUMBER: builtins.int
    IAP_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    OUTLIER_DETECTION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    affinity_cookie_ttl_sec: builtins.float
    connection_draining_timeout_sec: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    enable_cdn: builtins.bool
    fingerprint: builtins.str
    @property
    def health_checks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    load_balancing_scheme: builtins.str
    locality_lb_policy: builtins.str
    name: builtins.str
    network: builtins.str
    port_name: builtins.str
    project: builtins.str
    protocol: builtins.str
    region: builtins.str
    self_link: builtins.str
    session_affinity: builtins.str
    timeout_sec: builtins.float
    @property
    def backend(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionBackendServiceXBackend]: ...
    @property
    def cdn_policy(self) -> global___ComputeRegionBackendServiceXCdnPolicy: ...
    @property
    def circuit_breakers(self) -> global___ComputeRegionBackendServiceXCircuitBreakers: ...
    @property
    def consistent_hash(self) -> global___ComputeRegionBackendServiceXConsistentHash: ...
    @property
    def failover_policy(self) -> global___ComputeRegionBackendServiceXFailoverPolicy: ...
    @property
    def iap(self) -> global___ComputeRegionBackendServiceXIap: ...
    @property
    def log_config(self) -> global___ComputeRegionBackendServiceXLogConfig: ...
    @property
    def outlier_detection(self) -> global___ComputeRegionBackendServiceXOutlierDetection: ...
    @property
    def timeouts(self) -> global___ComputeRegionBackendServiceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        affinity_cookie_ttl_sec: builtins.float = ...,
        connection_draining_timeout_sec: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        enable_cdn: builtins.bool = ...,
        fingerprint: builtins.str = ...,
        health_checks: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
        load_balancing_scheme: builtins.str = ...,
        locality_lb_policy: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        port_name: builtins.str = ...,
        project: builtins.str = ...,
        protocol: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        session_affinity: builtins.str = ...,
        timeout_sec: builtins.float = ...,
        backend: collections.abc.Iterable[global___ComputeRegionBackendServiceXBackend] | None = ...,
        cdn_policy: global___ComputeRegionBackendServiceXCdnPolicy | None = ...,
        circuit_breakers: global___ComputeRegionBackendServiceXCircuitBreakers | None = ...,
        consistent_hash: global___ComputeRegionBackendServiceXConsistentHash | None = ...,
        failover_policy: global___ComputeRegionBackendServiceXFailoverPolicy | None = ...,
        iap: global___ComputeRegionBackendServiceXIap | None = ...,
        log_config: global___ComputeRegionBackendServiceXLogConfig | None = ...,
        outlier_detection: global___ComputeRegionBackendServiceXOutlierDetection | None = ...,
        timeouts: global___ComputeRegionBackendServiceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cdn_policy", b"cdn_policy", "circuit_breakers", b"circuit_breakers", "consistent_hash", b"consistent_hash", "failover_policy", b"failover_policy", "iap", b"iap", "log_config", b"log_config", "outlier_detection", b"outlier_detection", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["affinity_cookie_ttl_sec", b"affinity_cookie_ttl_sec", "backend", b"backend", "cdn_policy", b"cdn_policy", "circuit_breakers", b"circuit_breakers", "connection_draining_timeout_sec", b"connection_draining_timeout_sec", "consistent_hash", b"consistent_hash", "creation_timestamp", b"creation_timestamp", "description", b"description", "enable_cdn", b"enable_cdn", "failover_policy", b"failover_policy", "fingerprint", b"fingerprint", "health_checks", b"health_checks", "iap", b"iap", "id", b"id", "load_balancing_scheme", b"load_balancing_scheme", "locality_lb_policy", b"locality_lb_policy", "log_config", b"log_config", "name", b"name", "network", b"network", "outlier_detection", b"outlier_detection", "port_name", b"port_name", "project", b"project", "protocol", b"protocol", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "session_affinity", b"session_affinity", "timeout_sec", b"timeout_sec", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRegionBackendService = ComputeRegionBackendService

@typing_extensions.final
class ComputeRegionDiskXDiskEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    RAW_KEY_FIELD_NUMBER: builtins.int
    SHA256_FIELD_NUMBER: builtins.int
    kms_key_name: builtins.str
    raw_key: builtins.str
    sha256: builtins.str
    def __init__(
        self,
        *,
        kms_key_name: builtins.str = ...,
        raw_key: builtins.str = ...,
        sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_name", b"kms_key_name", "raw_key", b"raw_key", "sha256", b"sha256"]) -> None: ...

global___ComputeRegionDiskXDiskEncryptionKey = ComputeRegionDiskXDiskEncryptionKey

@typing_extensions.final
class ComputeRegionDiskXSourceSnapshotEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_KEY_FIELD_NUMBER: builtins.int
    SHA256_FIELD_NUMBER: builtins.int
    raw_key: builtins.str
    sha256: builtins.str
    def __init__(
        self,
        *,
        raw_key: builtins.str = ...,
        sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["raw_key", b"raw_key", "sha256", b"sha256"]) -> None: ...

global___ComputeRegionDiskXSourceSnapshotEncryptionKey = ComputeRegionDiskXSourceSnapshotEncryptionKey

@typing_extensions.final
class ComputeRegionDiskXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRegionDiskXTimeouts = ComputeRegionDiskXTimeouts

@typing_extensions.final
class ComputeRegionDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LAST_ATTACH_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_DETACH_TIMESTAMP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PHYSICAL_BLOCK_SIZE_BYTES_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    REPLICA_ZONES_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    SNAPSHOT_FIELD_NUMBER: builtins.int
    SOURCE_SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USERS_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    SOURCE_SNAPSHOT_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    label_fingerprint: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    last_attach_timestamp: builtins.str
    last_detach_timestamp: builtins.str
    name: builtins.str
    physical_block_size_bytes: builtins.float
    project: builtins.str
    region: builtins.str
    @property
    def replica_zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    self_link: builtins.str
    size: builtins.float
    snapshot: builtins.str
    source_snapshot_id: builtins.str
    type: builtins.str
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def disk_encryption_key(self) -> global___ComputeRegionDiskXDiskEncryptionKey: ...
    @property
    def source_snapshot_encryption_key(self) -> global___ComputeRegionDiskXSourceSnapshotEncryptionKey: ...
    @property
    def timeouts(self) -> global___ComputeRegionDiskXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        label_fingerprint: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        last_attach_timestamp: builtins.str = ...,
        last_detach_timestamp: builtins.str = ...,
        name: builtins.str = ...,
        physical_block_size_bytes: builtins.float = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        replica_zones: collections.abc.Iterable[builtins.str] | None = ...,
        self_link: builtins.str = ...,
        size: builtins.float = ...,
        snapshot: builtins.str = ...,
        source_snapshot_id: builtins.str = ...,
        type: builtins.str = ...,
        users: collections.abc.Iterable[builtins.str] | None = ...,
        disk_encryption_key: global___ComputeRegionDiskXDiskEncryptionKey | None = ...,
        source_snapshot_encryption_key: global___ComputeRegionDiskXSourceSnapshotEncryptionKey | None = ...,
        timeouts: global___ComputeRegionDiskXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_key", b"disk_encryption_key", "resource_info", b"resource_info", "source_snapshot_encryption_key", b"source_snapshot_encryption_key", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "disk_encryption_key", b"disk_encryption_key", "id", b"id", "label_fingerprint", b"label_fingerprint", "labels", b"labels", "last_attach_timestamp", b"last_attach_timestamp", "last_detach_timestamp", b"last_detach_timestamp", "name", b"name", "physical_block_size_bytes", b"physical_block_size_bytes", "project", b"project", "region", b"region", "replica_zones", b"replica_zones", "resource_info", b"resource_info", "self_link", b"self_link", "size", b"size", "snapshot", b"snapshot", "source_snapshot_encryption_key", b"source_snapshot_encryption_key", "source_snapshot_id", b"source_snapshot_id", "timeouts", b"timeouts", "type", b"type", "users", b"users"]) -> None: ...

global___ComputeRegionDisk = ComputeRegionDisk

@typing_extensions.final
class ComputeRegionDiskIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeRegionDiskIamBindingXCondition = ComputeRegionDiskIamBindingXCondition

@typing_extensions.final
class ComputeRegionDiskIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ComputeRegionDiskIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ComputeRegionDiskIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ComputeRegionDiskIamBinding = ComputeRegionDiskIamBinding

@typing_extensions.final
class ComputeRegionDiskIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeRegionDiskIamMemberXCondition = ComputeRegionDiskIamMemberXCondition

@typing_extensions.final
class ComputeRegionDiskIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ComputeRegionDiskIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ComputeRegionDiskIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ComputeRegionDiskIamMember = ComputeRegionDiskIamMember

@typing_extensions.final
class ComputeRegionDiskIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    name: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "name", b"name", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___ComputeRegionDiskIamPolicy = ComputeRegionDiskIamPolicy

@typing_extensions.final
class ComputeRegionDiskResourcePolicyAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeRegionDiskResourcePolicyAttachmentXTimeouts = ComputeRegionDiskResourcePolicyAttachmentXTimeouts

@typing_extensions.final
class ComputeRegionDiskResourcePolicyAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    disk: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def timeouts(self) -> global___ComputeRegionDiskResourcePolicyAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        disk: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        timeouts: global___ComputeRegionDiskResourcePolicyAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk", b"disk", "id", b"id", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRegionDiskResourcePolicyAttachment = ComputeRegionDiskResourcePolicyAttachment

@typing_extensions.final
class ComputeRegionHealthCheckXGrpcHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRPC_SERVICE_NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    grpc_service_name: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    def __init__(
        self,
        *,
        grpc_service_name: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grpc_service_name", b"grpc_service_name", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification"]) -> None: ...

global___ComputeRegionHealthCheckXGrpcHealthCheck = ComputeRegionHealthCheckXGrpcHealthCheck

@typing_extensions.final
class ComputeRegionHealthCheckXHttp2HealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    host: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request_path: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request_path: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request_path", b"request_path", "response", b"response"]) -> None: ...

global___ComputeRegionHealthCheckXHttp2HealthCheck = ComputeRegionHealthCheckXHttp2HealthCheck

@typing_extensions.final
class ComputeRegionHealthCheckXHttpHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    host: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request_path: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request_path: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request_path", b"request_path", "response", b"response"]) -> None: ...

global___ComputeRegionHealthCheckXHttpHealthCheck = ComputeRegionHealthCheckXHttpHealthCheck

@typing_extensions.final
class ComputeRegionHealthCheckXHttpsHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    host: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request_path: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request_path: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request_path", b"request_path", "response", b"response"]) -> None: ...

global___ComputeRegionHealthCheckXHttpsHealthCheck = ComputeRegionHealthCheckXHttpsHealthCheck

@typing_extensions.final
class ComputeRegionHealthCheckXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable"]) -> None: ...

global___ComputeRegionHealthCheckXLogConfig = ComputeRegionHealthCheckXLogConfig

@typing_extensions.final
class ComputeRegionHealthCheckXSslHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request", b"request", "response", b"response"]) -> None: ...

global___ComputeRegionHealthCheckXSslHealthCheck = ComputeRegionHealthCheckXSslHealthCheck

@typing_extensions.final
class ComputeRegionHealthCheckXTcpHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request", b"request", "response", b"response"]) -> None: ...

global___ComputeRegionHealthCheckXTcpHealthCheck = ComputeRegionHealthCheckXTcpHealthCheck

@typing_extensions.final
class ComputeRegionHealthCheckXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRegionHealthCheckXTimeouts = ComputeRegionHealthCheckXTimeouts

@typing_extensions.final
class ComputeRegionHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECK_INTERVAL_SEC_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    GRPC_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HTTP2_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HTTP_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HTTPS_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    SSL_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    TCP_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    check_interval_sec: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    healthy_threshold: builtins.float
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    timeout_sec: builtins.float
    type: builtins.str
    unhealthy_threshold: builtins.float
    @property
    def grpc_health_check(self) -> global___ComputeRegionHealthCheckXGrpcHealthCheck: ...
    @property
    def http2_health_check(self) -> global___ComputeRegionHealthCheckXHttp2HealthCheck: ...
    @property
    def http_health_check(self) -> global___ComputeRegionHealthCheckXHttpHealthCheck: ...
    @property
    def https_health_check(self) -> global___ComputeRegionHealthCheckXHttpsHealthCheck: ...
    @property
    def log_config(self) -> global___ComputeRegionHealthCheckXLogConfig: ...
    @property
    def ssl_health_check(self) -> global___ComputeRegionHealthCheckXSslHealthCheck: ...
    @property
    def tcp_health_check(self) -> global___ComputeRegionHealthCheckXTcpHealthCheck: ...
    @property
    def timeouts(self) -> global___ComputeRegionHealthCheckXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        check_interval_sec: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        healthy_threshold: builtins.float = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        timeout_sec: builtins.float = ...,
        type: builtins.str = ...,
        unhealthy_threshold: builtins.float = ...,
        grpc_health_check: global___ComputeRegionHealthCheckXGrpcHealthCheck | None = ...,
        http2_health_check: global___ComputeRegionHealthCheckXHttp2HealthCheck | None = ...,
        http_health_check: global___ComputeRegionHealthCheckXHttpHealthCheck | None = ...,
        https_health_check: global___ComputeRegionHealthCheckXHttpsHealthCheck | None = ...,
        log_config: global___ComputeRegionHealthCheckXLogConfig | None = ...,
        ssl_health_check: global___ComputeRegionHealthCheckXSslHealthCheck | None = ...,
        tcp_health_check: global___ComputeRegionHealthCheckXTcpHealthCheck | None = ...,
        timeouts: global___ComputeRegionHealthCheckXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["grpc_health_check", b"grpc_health_check", "http2_health_check", b"http2_health_check", "http_health_check", b"http_health_check", "https_health_check", b"https_health_check", "log_config", b"log_config", "resource_info", b"resource_info", "ssl_health_check", b"ssl_health_check", "tcp_health_check", b"tcp_health_check", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["check_interval_sec", b"check_interval_sec", "creation_timestamp", b"creation_timestamp", "description", b"description", "grpc_health_check", b"grpc_health_check", "healthy_threshold", b"healthy_threshold", "http2_health_check", b"http2_health_check", "http_health_check", b"http_health_check", "https_health_check", b"https_health_check", "id", b"id", "log_config", b"log_config", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "ssl_health_check", b"ssl_health_check", "tcp_health_check", b"tcp_health_check", "timeout_sec", b"timeout_sec", "timeouts", b"timeouts", "type", b"type", "unhealthy_threshold", b"unhealthy_threshold"]) -> None: ...

global___ComputeRegionHealthCheck = ComputeRegionHealthCheck

@typing_extensions.final
class ComputeRegionInstanceGroupManagerXAutoHealingPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_FIELD_NUMBER: builtins.int
    INITIAL_DELAY_SEC_FIELD_NUMBER: builtins.int
    health_check: builtins.str
    initial_delay_sec: builtins.float
    def __init__(
        self,
        *,
        health_check: builtins.str = ...,
        initial_delay_sec: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check", b"health_check", "initial_delay_sec", b"initial_delay_sec"]) -> None: ...

global___ComputeRegionInstanceGroupManagerXAutoHealingPolicies = ComputeRegionInstanceGroupManagerXAutoHealingPolicies

@typing_extensions.final
class ComputeRegionInstanceGroupManagerXNamedPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    name: builtins.str
    port: builtins.float
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        port: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "port", b"port"]) -> None: ...

global___ComputeRegionInstanceGroupManagerXNamedPort = ComputeRegionInstanceGroupManagerXNamedPort

@typing_extensions.final
class ComputeRegionInstanceGroupManagerXStatefulDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETE_RULE_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    delete_rule: builtins.str
    device_name: builtins.str
    def __init__(
        self,
        *,
        delete_rule: builtins.str = ...,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_rule", b"delete_rule", "device_name", b"device_name"]) -> None: ...

global___ComputeRegionInstanceGroupManagerXStatefulDisk = ComputeRegionInstanceGroupManagerXStatefulDisk

@typing_extensions.final
class ComputeRegionInstanceGroupManagerXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRegionInstanceGroupManagerXTimeouts = ComputeRegionInstanceGroupManagerXTimeouts

@typing_extensions.final
class ComputeRegionInstanceGroupManagerXUpdatePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_REDISTRIBUTION_TYPE_FIELD_NUMBER: builtins.int
    MAX_SURGE_FIXED_FIELD_NUMBER: builtins.int
    MAX_SURGE_PERCENT_FIELD_NUMBER: builtins.int
    MAX_UNAVAILABLE_FIXED_FIELD_NUMBER: builtins.int
    MAX_UNAVAILABLE_PERCENT_FIELD_NUMBER: builtins.int
    MINIMAL_ACTION_FIELD_NUMBER: builtins.int
    MOST_DISRUPTIVE_ALLOWED_ACTION_FIELD_NUMBER: builtins.int
    REPLACEMENT_METHOD_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    instance_redistribution_type: builtins.str
    max_surge_fixed: builtins.float
    max_surge_percent: builtins.float
    max_unavailable_fixed: builtins.float
    max_unavailable_percent: builtins.float
    minimal_action: builtins.str
    most_disruptive_allowed_action: builtins.str
    replacement_method: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        instance_redistribution_type: builtins.str = ...,
        max_surge_fixed: builtins.float = ...,
        max_surge_percent: builtins.float = ...,
        max_unavailable_fixed: builtins.float = ...,
        max_unavailable_percent: builtins.float = ...,
        minimal_action: builtins.str = ...,
        most_disruptive_allowed_action: builtins.str = ...,
        replacement_method: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_redistribution_type", b"instance_redistribution_type", "max_surge_fixed", b"max_surge_fixed", "max_surge_percent", b"max_surge_percent", "max_unavailable_fixed", b"max_unavailable_fixed", "max_unavailable_percent", b"max_unavailable_percent", "minimal_action", b"minimal_action", "most_disruptive_allowed_action", b"most_disruptive_allowed_action", "replacement_method", b"replacement_method", "type", b"type"]) -> None: ...

global___ComputeRegionInstanceGroupManagerXUpdatePolicy = ComputeRegionInstanceGroupManagerXUpdatePolicy

@typing_extensions.final
class ComputeRegionInstanceGroupManagerXVersionXTargetSize(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIXED_FIELD_NUMBER: builtins.int
    PERCENT_FIELD_NUMBER: builtins.int
    fixed: builtins.float
    percent: builtins.float
    def __init__(
        self,
        *,
        fixed: builtins.float = ...,
        percent: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed", b"fixed", "percent", b"percent"]) -> None: ...

global___ComputeRegionInstanceGroupManagerXVersionXTargetSize = ComputeRegionInstanceGroupManagerXVersionXTargetSize

@typing_extensions.final
class ComputeRegionInstanceGroupManagerXVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_TEMPLATE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_SIZE_FIELD_NUMBER: builtins.int
    instance_template: builtins.str
    name: builtins.str
    @property
    def target_size(self) -> global___ComputeRegionInstanceGroupManagerXVersionXTargetSize: ...
    def __init__(
        self,
        *,
        instance_template: builtins.str = ...,
        name: builtins.str = ...,
        target_size: global___ComputeRegionInstanceGroupManagerXVersionXTargetSize | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["target_size", b"target_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_template", b"instance_template", "name", b"name", "target_size", b"target_size"]) -> None: ...

global___ComputeRegionInstanceGroupManagerXVersion = ComputeRegionInstanceGroupManagerXVersion

@typing_extensions.final
class ComputeRegionInstanceGroupManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class StatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BASE_INSTANCE_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISTRIBUTION_POLICY_TARGET_SHAPE_FIELD_NUMBER: builtins.int
    DISTRIBUTION_POLICY_ZONES_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_GROUP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TARGET_POOLS_FIELD_NUMBER: builtins.int
    TARGET_SIZE_FIELD_NUMBER: builtins.int
    WAIT_FOR_INSTANCES_FIELD_NUMBER: builtins.int
    WAIT_FOR_INSTANCES_STATUS_FIELD_NUMBER: builtins.int
    AUTO_HEALING_POLICIES_FIELD_NUMBER: builtins.int
    NAMED_PORT_FIELD_NUMBER: builtins.int
    STATEFUL_DISK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    UPDATE_POLICY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    base_instance_name: builtins.str
    description: builtins.str
    distribution_policy_target_shape: builtins.str
    @property
    def distribution_policy_zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    fingerprint: builtins.str
    id: builtins.str
    instance_group: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def status(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def target_pools(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    target_size: builtins.float
    wait_for_instances: builtins.bool
    wait_for_instances_status: builtins.str
    @property
    def auto_healing_policies(self) -> global___ComputeRegionInstanceGroupManagerXAutoHealingPolicies: ...
    @property
    def named_port(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionInstanceGroupManagerXNamedPort]: ...
    @property
    def stateful_disk(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionInstanceGroupManagerXStatefulDisk]: ...
    @property
    def timeouts(self) -> global___ComputeRegionInstanceGroupManagerXTimeouts: ...
    @property
    def update_policy(self) -> global___ComputeRegionInstanceGroupManagerXUpdatePolicy: ...
    @property
    def version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionInstanceGroupManagerXVersion]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        base_instance_name: builtins.str = ...,
        description: builtins.str = ...,
        distribution_policy_target_shape: builtins.str = ...,
        distribution_policy_zones: collections.abc.Iterable[builtins.str] | None = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        instance_group: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        status: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        target_pools: collections.abc.Iterable[builtins.str] | None = ...,
        target_size: builtins.float = ...,
        wait_for_instances: builtins.bool = ...,
        wait_for_instances_status: builtins.str = ...,
        auto_healing_policies: global___ComputeRegionInstanceGroupManagerXAutoHealingPolicies | None = ...,
        named_port: collections.abc.Iterable[global___ComputeRegionInstanceGroupManagerXNamedPort] | None = ...,
        stateful_disk: collections.abc.Iterable[global___ComputeRegionInstanceGroupManagerXStatefulDisk] | None = ...,
        timeouts: global___ComputeRegionInstanceGroupManagerXTimeouts | None = ...,
        update_policy: global___ComputeRegionInstanceGroupManagerXUpdatePolicy | None = ...,
        version: collections.abc.Iterable[global___ComputeRegionInstanceGroupManagerXVersion] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_healing_policies", b"auto_healing_policies", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_policy", b"update_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_healing_policies", b"auto_healing_policies", "base_instance_name", b"base_instance_name", "description", b"description", "distribution_policy_target_shape", b"distribution_policy_target_shape", "distribution_policy_zones", b"distribution_policy_zones", "fingerprint", b"fingerprint", "id", b"id", "instance_group", b"instance_group", "name", b"name", "named_port", b"named_port", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "stateful_disk", b"stateful_disk", "status", b"status", "target_pools", b"target_pools", "target_size", b"target_size", "timeouts", b"timeouts", "update_policy", b"update_policy", "version", b"version", "wait_for_instances", b"wait_for_instances", "wait_for_instances_status", b"wait_for_instances_status"]) -> None: ...

global___ComputeRegionInstanceGroupManager = ComputeRegionInstanceGroupManager

@typing_extensions.final
class ComputeRegionNetworkEndpointGroupXAppEngine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    URL_MASK_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    service: builtins.str
    url_mask: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        service: builtins.str = ...,
        url_mask: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service", b"service", "url_mask", b"url_mask", "version", b"version"]) -> None: ...

global___ComputeRegionNetworkEndpointGroupXAppEngine = ComputeRegionNetworkEndpointGroupXAppEngine

@typing_extensions.final
class ComputeRegionNetworkEndpointGroupXCloudFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_FIELD_NUMBER: builtins.int
    URL_MASK_FIELD_NUMBER: builtins.int
    function: builtins.str
    url_mask: builtins.str
    def __init__(
        self,
        *,
        function: builtins.str = ...,
        url_mask: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["function", b"function", "url_mask", b"url_mask"]) -> None: ...

global___ComputeRegionNetworkEndpointGroupXCloudFunction = ComputeRegionNetworkEndpointGroupXCloudFunction

@typing_extensions.final
class ComputeRegionNetworkEndpointGroupXCloudRun(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    URL_MASK_FIELD_NUMBER: builtins.int
    service: builtins.str
    tag: builtins.str
    url_mask: builtins.str
    def __init__(
        self,
        *,
        service: builtins.str = ...,
        tag: builtins.str = ...,
        url_mask: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service", b"service", "tag", b"tag", "url_mask", b"url_mask"]) -> None: ...

global___ComputeRegionNetworkEndpointGroupXCloudRun = ComputeRegionNetworkEndpointGroupXCloudRun

@typing_extensions.final
class ComputeRegionNetworkEndpointGroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeRegionNetworkEndpointGroupXTimeouts = ComputeRegionNetworkEndpointGroupXTimeouts

@typing_extensions.final
class ComputeRegionNetworkEndpointGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORK_ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PSC_TARGET_SERVICE_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    APP_ENGINE_FIELD_NUMBER: builtins.int
    CLOUD_FUNCTION_FIELD_NUMBER: builtins.int
    CLOUD_RUN_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    name: builtins.str
    network: builtins.str
    network_endpoint_type: builtins.str
    project: builtins.str
    psc_target_service: builtins.str
    region: builtins.str
    self_link: builtins.str
    subnetwork: builtins.str
    @property
    def app_engine(self) -> global___ComputeRegionNetworkEndpointGroupXAppEngine: ...
    @property
    def cloud_function(self) -> global___ComputeRegionNetworkEndpointGroupXCloudFunction: ...
    @property
    def cloud_run(self) -> global___ComputeRegionNetworkEndpointGroupXCloudRun: ...
    @property
    def timeouts(self) -> global___ComputeRegionNetworkEndpointGroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        network_endpoint_type: builtins.str = ...,
        project: builtins.str = ...,
        psc_target_service: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        subnetwork: builtins.str = ...,
        app_engine: global___ComputeRegionNetworkEndpointGroupXAppEngine | None = ...,
        cloud_function: global___ComputeRegionNetworkEndpointGroupXCloudFunction | None = ...,
        cloud_run: global___ComputeRegionNetworkEndpointGroupXCloudRun | None = ...,
        timeouts: global___ComputeRegionNetworkEndpointGroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_engine", b"app_engine", "cloud_function", b"cloud_function", "cloud_run", b"cloud_run", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_engine", b"app_engine", "cloud_function", b"cloud_function", "cloud_run", b"cloud_run", "description", b"description", "id", b"id", "name", b"name", "network", b"network", "network_endpoint_type", b"network_endpoint_type", "project", b"project", "psc_target_service", b"psc_target_service", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "subnetwork", b"subnetwork", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRegionNetworkEndpointGroup = ComputeRegionNetworkEndpointGroup

@typing_extensions.final
class ComputeRegionPerInstanceConfigXPreservedStateXDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETE_RULE_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    delete_rule: builtins.str
    device_name: builtins.str
    mode: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        delete_rule: builtins.str = ...,
        device_name: builtins.str = ...,
        mode: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_rule", b"delete_rule", "device_name", b"device_name", "mode", b"mode", "source", b"source"]) -> None: ...

global___ComputeRegionPerInstanceConfigXPreservedStateXDisk = ComputeRegionPerInstanceConfigXPreservedStateXDisk

@typing_extensions.final
class ComputeRegionPerInstanceConfigXPreservedState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    METADATA_FIELD_NUMBER: builtins.int
    DISK_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def disk(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionPerInstanceConfigXPreservedStateXDisk]: ...
    def __init__(
        self,
        *,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        disk: collections.abc.Iterable[global___ComputeRegionPerInstanceConfigXPreservedStateXDisk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk", b"disk", "metadata", b"metadata"]) -> None: ...

global___ComputeRegionPerInstanceConfigXPreservedState = ComputeRegionPerInstanceConfigXPreservedState

@typing_extensions.final
class ComputeRegionPerInstanceConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRegionPerInstanceConfigXTimeouts = ComputeRegionPerInstanceConfigXTimeouts

@typing_extensions.final
class ComputeRegionPerInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    MINIMAL_ACTION_FIELD_NUMBER: builtins.int
    MOST_DISRUPTIVE_ALLOWED_ACTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    REGION_INSTANCE_GROUP_MANAGER_FIELD_NUMBER: builtins.int
    REMOVE_INSTANCE_STATE_ON_DESTROY_FIELD_NUMBER: builtins.int
    PRESERVED_STATE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    minimal_action: builtins.str
    most_disruptive_allowed_action: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    region_instance_group_manager: builtins.str
    remove_instance_state_on_destroy: builtins.bool
    @property
    def preserved_state(self) -> global___ComputeRegionPerInstanceConfigXPreservedState: ...
    @property
    def timeouts(self) -> global___ComputeRegionPerInstanceConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        minimal_action: builtins.str = ...,
        most_disruptive_allowed_action: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        region_instance_group_manager: builtins.str = ...,
        remove_instance_state_on_destroy: builtins.bool = ...,
        preserved_state: global___ComputeRegionPerInstanceConfigXPreservedState | None = ...,
        timeouts: global___ComputeRegionPerInstanceConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preserved_state", b"preserved_state", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "minimal_action", b"minimal_action", "most_disruptive_allowed_action", b"most_disruptive_allowed_action", "name", b"name", "preserved_state", b"preserved_state", "project", b"project", "region", b"region", "region_instance_group_manager", b"region_instance_group_manager", "remove_instance_state_on_destroy", b"remove_instance_state_on_destroy", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRegionPerInstanceConfig = ComputeRegionPerInstanceConfig

@typing_extensions.final
class ComputeRegionSslCertificateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeRegionSslCertificateXTimeouts = ComputeRegionSslCertificateXTimeouts

@typing_extensions.final
class ComputeRegionSslCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAME_PREFIX_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    certificate: builtins.str
    certificate_id: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    name_prefix: builtins.str
    private_key: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeRegionSslCertificateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        certificate: builtins.str = ...,
        certificate_id: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        name_prefix: builtins.str = ...,
        private_key: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeRegionSslCertificateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "certificate_id", b"certificate_id", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "name_prefix", b"name_prefix", "private_key", b"private_key", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRegionSslCertificate = ComputeRegionSslCertificate

@typing_extensions.final
class ComputeRegionTargetHttpProxyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRegionTargetHttpProxyXTimeouts = ComputeRegionTargetHttpProxyXTimeouts

@typing_extensions.final
class ComputeRegionTargetHttpProxy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROXY_ID_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    URL_MAP_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    proxy_id: builtins.float
    region: builtins.str
    self_link: builtins.str
    url_map: builtins.str
    @property
    def timeouts(self) -> global___ComputeRegionTargetHttpProxyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        proxy_id: builtins.float = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        url_map: builtins.str = ...,
        timeouts: global___ComputeRegionTargetHttpProxyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "proxy_id", b"proxy_id", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts", "url_map", b"url_map"]) -> None: ...

global___ComputeRegionTargetHttpProxy = ComputeRegionTargetHttpProxy

@typing_extensions.final
class ComputeRegionTargetHttpsProxyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRegionTargetHttpsProxyXTimeouts = ComputeRegionTargetHttpsProxyXTimeouts

@typing_extensions.final
class ComputeRegionTargetHttpsProxy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROXY_ID_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATES_FIELD_NUMBER: builtins.int
    URL_MAP_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    proxy_id: builtins.float
    region: builtins.str
    self_link: builtins.str
    @property
    def ssl_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    url_map: builtins.str
    @property
    def timeouts(self) -> global___ComputeRegionTargetHttpsProxyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        proxy_id: builtins.float = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        ssl_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        url_map: builtins.str = ...,
        timeouts: global___ComputeRegionTargetHttpsProxyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "proxy_id", b"proxy_id", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "ssl_certificates", b"ssl_certificates", "timeouts", b"timeouts", "url_map", b"url_map"]) -> None: ...

global___ComputeRegionTargetHttpsProxy = ComputeRegionTargetHttpsProxy

@typing_extensions.final
class ComputeRegionUrlMapXDefaultUrlRedirect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REDIRECT_FIELD_NUMBER: builtins.int
    HTTPS_REDIRECT_FIELD_NUMBER: builtins.int
    PATH_REDIRECT_FIELD_NUMBER: builtins.int
    PREFIX_REDIRECT_FIELD_NUMBER: builtins.int
    REDIRECT_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    STRIP_QUERY_FIELD_NUMBER: builtins.int
    host_redirect: builtins.str
    https_redirect: builtins.bool
    path_redirect: builtins.str
    prefix_redirect: builtins.str
    redirect_response_code: builtins.str
    strip_query: builtins.bool
    def __init__(
        self,
        *,
        host_redirect: builtins.str = ...,
        https_redirect: builtins.bool = ...,
        path_redirect: builtins.str = ...,
        prefix_redirect: builtins.str = ...,
        redirect_response_code: builtins.str = ...,
        strip_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_redirect", b"host_redirect", "https_redirect", b"https_redirect", "path_redirect", b"path_redirect", "prefix_redirect", b"prefix_redirect", "redirect_response_code", b"redirect_response_code", "strip_query", b"strip_query"]) -> None: ...

global___ComputeRegionUrlMapXDefaultUrlRedirect = ComputeRegionUrlMapXDefaultUrlRedirect

@typing_extensions.final
class ComputeRegionUrlMapXHostRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    PATH_MATCHER_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    path_matcher: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        path_matcher: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "hosts", b"hosts", "path_matcher", b"path_matcher"]) -> None: ...

global___ComputeRegionUrlMapXHostRule = ComputeRegionUrlMapXHostRule

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXDefaultUrlRedirect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REDIRECT_FIELD_NUMBER: builtins.int
    HTTPS_REDIRECT_FIELD_NUMBER: builtins.int
    PATH_REDIRECT_FIELD_NUMBER: builtins.int
    PREFIX_REDIRECT_FIELD_NUMBER: builtins.int
    REDIRECT_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    STRIP_QUERY_FIELD_NUMBER: builtins.int
    host_redirect: builtins.str
    https_redirect: builtins.bool
    path_redirect: builtins.str
    prefix_redirect: builtins.str
    redirect_response_code: builtins.str
    strip_query: builtins.bool
    def __init__(
        self,
        *,
        host_redirect: builtins.str = ...,
        https_redirect: builtins.bool = ...,
        path_redirect: builtins.str = ...,
        prefix_redirect: builtins.str = ...,
        redirect_response_code: builtins.str = ...,
        strip_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_redirect", b"host_redirect", "https_redirect", b"https_redirect", "path_redirect", b"path_redirect", "prefix_redirect", b"prefix_redirect", "redirect_response_code", b"redirect_response_code", "strip_query", b"strip_query"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXDefaultUrlRedirect = ComputeRegionUrlMapXPathMatcherXDefaultUrlRedirect

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    ALLOW_HEADERS_FIELD_NUMBER: builtins.int
    ALLOW_METHODS_FIELD_NUMBER: builtins.int
    ALLOW_ORIGIN_REGEXES_FIELD_NUMBER: builtins.int
    ALLOW_ORIGINS_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    EXPOSE_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def allow_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origin_regexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    disabled: builtins.bool
    @property
    def expose_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.float
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        allow_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allow_methods: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origin_regexes: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origins: collections.abc.Iterable[builtins.str] | None = ...,
        disabled: builtins.bool = ...,
        expose_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "allow_headers", b"allow_headers", "allow_methods", b"allow_methods", "allow_origin_regexes", b"allow_origin_regexes", "allow_origins", b"allow_origins", "disabled", b"disabled", "expose_headers", b"expose_headers", "max_age", b"max_age"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_STATUS_FIELD_NUMBER: builtins.int
    PERCENTAGE_FIELD_NUMBER: builtins.int
    http_status: builtins.float
    percentage: builtins.float
    def __init__(
        self,
        *,
        http_status: builtins.float = ...,
        percentage: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_status", b"http_status", "percentage", b"percentage"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERCENTAGE_FIELD_NUMBER: builtins.int
    FIXED_DELAY_FIELD_NUMBER: builtins.int
    percentage: builtins.float
    @property
    def fixed_delay(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay: ...
    def __init__(
        self,
        *,
        percentage: builtins.float = ...,
        fixed_delay: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay", "percentage", b"percentage"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ABORT_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    @property
    def abort(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort: ...
    @property
    def delay(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay: ...
    def __init__(
        self,
        *,
        abort: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort | None = ...,
        delay: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_RETRIES_FIELD_NUMBER: builtins.int
    RETRY_CONDITIONS_FIELD_NUMBER: builtins.int
    PER_TRY_TIMEOUT_FIELD_NUMBER: builtins.int
    num_retries: builtins.float
    @property
    def retry_conditions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def per_try_timeout(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout: ...
    def __init__(
        self,
        *,
        num_retries: builtins.float = ...,
        retry_conditions: collections.abc.Iterable[builtins.str] | None = ...,
        per_try_timeout: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["per_try_timeout", b"per_try_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_retries", b"num_retries", "per_try_timeout", b"per_try_timeout", "retry_conditions", b"retry_conditions"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXTimeout = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXTimeout

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REWRITE_FIELD_NUMBER: builtins.int
    PATH_PREFIX_REWRITE_FIELD_NUMBER: builtins.int
    host_rewrite: builtins.str
    path_prefix_rewrite: builtins.str
    def __init__(
        self,
        *,
        host_rewrite: builtins.str = ...,
        path_prefix_rewrite: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_rewrite", b"host_rewrite", "path_prefix_rewrite", b"path_prefix_rewrite"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    @property
    def request_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def request_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd]: ...
    @property
    def response_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd]: ...
    def __init__(
        self,
        *,
        request_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        response_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        request_headers_to_add: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd] | None = ...,
        response_headers_to_add: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_headers_to_add", b"request_headers_to_add", "request_headers_to_remove", b"request_headers_to_remove", "response_headers_to_add", b"response_headers_to_add", "response_headers_to_remove", b"response_headers_to_remove"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    weight: builtins.float
    @property
    def header_action(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction: ...
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
        weight: builtins.float = ...,
        header_action: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header_action", b"header_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service", "header_action", b"header_action", "weight", b"weight"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXRouteAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORS_POLICY_FIELD_NUMBER: builtins.int
    FAULT_INJECTION_POLICY_FIELD_NUMBER: builtins.int
    REQUEST_MIRROR_POLICY_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    URL_REWRITE_FIELD_NUMBER: builtins.int
    WEIGHTED_BACKEND_SERVICES_FIELD_NUMBER: builtins.int
    @property
    def cors_policy(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy: ...
    @property
    def fault_injection_policy(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy: ...
    @property
    def request_mirror_policy(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy: ...
    @property
    def retry_policy(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy: ...
    @property
    def timeout(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXTimeout: ...
    @property
    def url_rewrite(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite: ...
    @property
    def weighted_backend_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices]: ...
    def __init__(
        self,
        *,
        cors_policy: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy | None = ...,
        fault_injection_policy: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy | None = ...,
        request_mirror_policy: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy | None = ...,
        retry_policy: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy | None = ...,
        timeout: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXTimeout | None = ...,
        url_rewrite: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite | None = ...,
        weighted_backend_services: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite", "weighted_backend_services", b"weighted_backend_services"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteAction = ComputeRegionUrlMapXPathMatcherXPathRuleXRouteAction

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRuleXUrlRedirect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REDIRECT_FIELD_NUMBER: builtins.int
    HTTPS_REDIRECT_FIELD_NUMBER: builtins.int
    PATH_REDIRECT_FIELD_NUMBER: builtins.int
    PREFIX_REDIRECT_FIELD_NUMBER: builtins.int
    REDIRECT_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    STRIP_QUERY_FIELD_NUMBER: builtins.int
    host_redirect: builtins.str
    https_redirect: builtins.bool
    path_redirect: builtins.str
    prefix_redirect: builtins.str
    redirect_response_code: builtins.str
    strip_query: builtins.bool
    def __init__(
        self,
        *,
        host_redirect: builtins.str = ...,
        https_redirect: builtins.bool = ...,
        path_redirect: builtins.str = ...,
        prefix_redirect: builtins.str = ...,
        redirect_response_code: builtins.str = ...,
        strip_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_redirect", b"host_redirect", "https_redirect", b"https_redirect", "path_redirect", b"path_redirect", "prefix_redirect", b"prefix_redirect", "redirect_response_code", b"redirect_response_code", "strip_query", b"strip_query"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRuleXUrlRedirect = ComputeRegionUrlMapXPathMatcherXPathRuleXUrlRedirect

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXPathRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATHS_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    ROUTE_ACTION_FIELD_NUMBER: builtins.int
    URL_REDIRECT_FIELD_NUMBER: builtins.int
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service: builtins.str
    @property
    def route_action(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteAction: ...
    @property
    def url_redirect(self) -> global___ComputeRegionUrlMapXPathMatcherXPathRuleXUrlRedirect: ...
    def __init__(
        self,
        *,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        service: builtins.str = ...,
        route_action: global___ComputeRegionUrlMapXPathMatcherXPathRuleXRouteAction | None = ...,
        url_redirect: global___ComputeRegionUrlMapXPathMatcherXPathRuleXUrlRedirect | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["route_action", b"route_action", "url_redirect", b"url_redirect"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["paths", b"paths", "route_action", b"route_action", "service", b"service", "url_redirect", b"url_redirect"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXPathRule = ComputeRegionUrlMapXPathMatcherXPathRule

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd = ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd = ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    @property
    def request_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def request_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd]: ...
    @property
    def response_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd]: ...
    def __init__(
        self,
        *,
        request_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        response_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        request_headers_to_add: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd] | None = ...,
        response_headers_to_add: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_headers_to_add", b"request_headers_to_add", "request_headers_to_remove", b"request_headers_to_remove", "response_headers_to_add", b"response_headers_to_add", "response_headers_to_remove", b"response_headers_to_remove"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderAction = ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderAction

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RANGE_END_FIELD_NUMBER: builtins.int
    RANGE_START_FIELD_NUMBER: builtins.int
    range_end: builtins.float
    range_start: builtins.float
    def __init__(
        self,
        *,
        range_end: builtins.float = ...,
        range_start: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["range_end", b"range_end", "range_start", b"range_start"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch = ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXACT_MATCH_FIELD_NUMBER: builtins.int
    HEADER_NAME_FIELD_NUMBER: builtins.int
    INVERT_MATCH_FIELD_NUMBER: builtins.int
    PREFIX_MATCH_FIELD_NUMBER: builtins.int
    PRESENT_MATCH_FIELD_NUMBER: builtins.int
    REGEX_MATCH_FIELD_NUMBER: builtins.int
    SUFFIX_MATCH_FIELD_NUMBER: builtins.int
    RANGE_MATCH_FIELD_NUMBER: builtins.int
    exact_match: builtins.str
    header_name: builtins.str
    invert_match: builtins.bool
    prefix_match: builtins.str
    present_match: builtins.bool
    regex_match: builtins.str
    suffix_match: builtins.str
    @property
    def range_match(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch: ...
    def __init__(
        self,
        *,
        exact_match: builtins.str = ...,
        header_name: builtins.str = ...,
        invert_match: builtins.bool = ...,
        prefix_match: builtins.str = ...,
        present_match: builtins.bool = ...,
        regex_match: builtins.str = ...,
        suffix_match: builtins.str = ...,
        range_match: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["range_match", b"range_match"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exact_match", b"exact_match", "header_name", b"header_name", "invert_match", b"invert_match", "prefix_match", b"prefix_match", "present_match", b"present_match", "range_match", b"range_match", "regex_match", b"regex_match", "suffix_match", b"suffix_match"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches = ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels = ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTER_MATCH_CRITERIA_FIELD_NUMBER: builtins.int
    FILTER_LABELS_FIELD_NUMBER: builtins.int
    filter_match_criteria: builtins.str
    @property
    def filter_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels]: ...
    def __init__(
        self,
        *,
        filter_match_criteria: builtins.str = ...,
        filter_labels: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter_labels", b"filter_labels", "filter_match_criteria", b"filter_match_criteria"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters = ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXACT_MATCH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRESENT_MATCH_FIELD_NUMBER: builtins.int
    REGEX_MATCH_FIELD_NUMBER: builtins.int
    exact_match: builtins.str
    name: builtins.str
    present_match: builtins.bool
    regex_match: builtins.str
    def __init__(
        self,
        *,
        exact_match: builtins.str = ...,
        name: builtins.str = ...,
        present_match: builtins.bool = ...,
        regex_match: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exact_match", b"exact_match", "name", b"name", "present_match", b"present_match", "regex_match", b"regex_match"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches = ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULL_PATH_MATCH_FIELD_NUMBER: builtins.int
    IGNORE_CASE_FIELD_NUMBER: builtins.int
    PREFIX_MATCH_FIELD_NUMBER: builtins.int
    REGEX_MATCH_FIELD_NUMBER: builtins.int
    HEADER_MATCHES_FIELD_NUMBER: builtins.int
    METADATA_FILTERS_FIELD_NUMBER: builtins.int
    QUERY_PARAMETER_MATCHES_FIELD_NUMBER: builtins.int
    full_path_match: builtins.str
    ignore_case: builtins.bool
    prefix_match: builtins.str
    regex_match: builtins.str
    @property
    def header_matches(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches]: ...
    @property
    def metadata_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters]: ...
    @property
    def query_parameter_matches(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches]: ...
    def __init__(
        self,
        *,
        full_path_match: builtins.str = ...,
        ignore_case: builtins.bool = ...,
        prefix_match: builtins.str = ...,
        regex_match: builtins.str = ...,
        header_matches: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches] | None = ...,
        metadata_filters: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters] | None = ...,
        query_parameter_matches: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["full_path_match", b"full_path_match", "header_matches", b"header_matches", "ignore_case", b"ignore_case", "metadata_filters", b"metadata_filters", "prefix_match", b"prefix_match", "query_parameter_matches", b"query_parameter_matches", "regex_match", b"regex_match"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRules = ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRules

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    ALLOW_HEADERS_FIELD_NUMBER: builtins.int
    ALLOW_METHODS_FIELD_NUMBER: builtins.int
    ALLOW_ORIGIN_REGEXES_FIELD_NUMBER: builtins.int
    ALLOW_ORIGINS_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    EXPOSE_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def allow_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origin_regexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    disabled: builtins.bool
    @property
    def expose_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.float
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        allow_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allow_methods: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origin_regexes: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origins: collections.abc.Iterable[builtins.str] | None = ...,
        disabled: builtins.bool = ...,
        expose_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "allow_headers", b"allow_headers", "allow_methods", b"allow_methods", "allow_origin_regexes", b"allow_origin_regexes", "allow_origins", b"allow_origins", "disabled", b"disabled", "expose_headers", b"expose_headers", "max_age", b"max_age"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_STATUS_FIELD_NUMBER: builtins.int
    PERCENTAGE_FIELD_NUMBER: builtins.int
    http_status: builtins.float
    percentage: builtins.float
    def __init__(
        self,
        *,
        http_status: builtins.float = ...,
        percentage: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_status", b"http_status", "percentage", b"percentage"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERCENTAGE_FIELD_NUMBER: builtins.int
    FIXED_DELAY_FIELD_NUMBER: builtins.int
    percentage: builtins.float
    @property
    def fixed_delay(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay: ...
    def __init__(
        self,
        *,
        percentage: builtins.float = ...,
        fixed_delay: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay", "percentage", b"percentage"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ABORT_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    @property
    def abort(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort: ...
    @property
    def delay(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay: ...
    def __init__(
        self,
        *,
        abort: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort | None = ...,
        delay: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_RETRIES_FIELD_NUMBER: builtins.int
    RETRY_CONDITIONS_FIELD_NUMBER: builtins.int
    PER_TRY_TIMEOUT_FIELD_NUMBER: builtins.int
    num_retries: builtins.float
    @property
    def retry_conditions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def per_try_timeout(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout: ...
    def __init__(
        self,
        *,
        num_retries: builtins.float = ...,
        retry_conditions: collections.abc.Iterable[builtins.str] | None = ...,
        per_try_timeout: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["per_try_timeout", b"per_try_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_retries", b"num_retries", "per_try_timeout", b"per_try_timeout", "retry_conditions", b"retry_conditions"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REWRITE_FIELD_NUMBER: builtins.int
    PATH_PREFIX_REWRITE_FIELD_NUMBER: builtins.int
    host_rewrite: builtins.str
    path_prefix_rewrite: builtins.str
    def __init__(
        self,
        *,
        host_rewrite: builtins.str = ...,
        path_prefix_rewrite: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_rewrite", b"host_rewrite", "path_prefix_rewrite", b"path_prefix_rewrite"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    @property
    def request_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def request_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd]: ...
    @property
    def response_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd]: ...
    def __init__(
        self,
        *,
        request_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        response_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        request_headers_to_add: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd] | None = ...,
        response_headers_to_add: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_headers_to_add", b"request_headers_to_add", "request_headers_to_remove", b"request_headers_to_remove", "response_headers_to_add", b"response_headers_to_add", "response_headers_to_remove", b"response_headers_to_remove"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    weight: builtins.float
    @property
    def header_action(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction: ...
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
        weight: builtins.float = ...,
        header_action: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header_action", b"header_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service", "header_action", b"header_action", "weight", b"weight"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORS_POLICY_FIELD_NUMBER: builtins.int
    FAULT_INJECTION_POLICY_FIELD_NUMBER: builtins.int
    REQUEST_MIRROR_POLICY_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    URL_REWRITE_FIELD_NUMBER: builtins.int
    WEIGHTED_BACKEND_SERVICES_FIELD_NUMBER: builtins.int
    @property
    def cors_policy(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy: ...
    @property
    def fault_injection_policy(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy: ...
    @property
    def request_mirror_policy(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy: ...
    @property
    def retry_policy(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy: ...
    @property
    def timeout(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout: ...
    @property
    def url_rewrite(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite: ...
    @property
    def weighted_backend_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices]: ...
    def __init__(
        self,
        *,
        cors_policy: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy | None = ...,
        fault_injection_policy: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy | None = ...,
        request_mirror_policy: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy | None = ...,
        retry_policy: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy | None = ...,
        timeout: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout | None = ...,
        url_rewrite: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite | None = ...,
        weighted_backend_services: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite", "weighted_backend_services", b"weighted_backend_services"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteAction = ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteAction

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRulesXUrlRedirect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REDIRECT_FIELD_NUMBER: builtins.int
    HTTPS_REDIRECT_FIELD_NUMBER: builtins.int
    PATH_REDIRECT_FIELD_NUMBER: builtins.int
    PREFIX_REDIRECT_FIELD_NUMBER: builtins.int
    REDIRECT_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    STRIP_QUERY_FIELD_NUMBER: builtins.int
    host_redirect: builtins.str
    https_redirect: builtins.bool
    path_redirect: builtins.str
    prefix_redirect: builtins.str
    redirect_response_code: builtins.str
    strip_query: builtins.bool
    def __init__(
        self,
        *,
        host_redirect: builtins.str = ...,
        https_redirect: builtins.bool = ...,
        path_redirect: builtins.str = ...,
        prefix_redirect: builtins.str = ...,
        redirect_response_code: builtins.str = ...,
        strip_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_redirect", b"host_redirect", "https_redirect", b"https_redirect", "path_redirect", b"path_redirect", "prefix_redirect", b"prefix_redirect", "redirect_response_code", b"redirect_response_code", "strip_query", b"strip_query"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRulesXUrlRedirect = ComputeRegionUrlMapXPathMatcherXRouteRulesXUrlRedirect

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcherXRouteRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIORITY_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    MATCH_RULES_FIELD_NUMBER: builtins.int
    ROUTE_ACTION_FIELD_NUMBER: builtins.int
    URL_REDIRECT_FIELD_NUMBER: builtins.int
    priority: builtins.float
    service: builtins.str
    @property
    def header_action(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderAction: ...
    @property
    def match_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRules]: ...
    @property
    def route_action(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteAction: ...
    @property
    def url_redirect(self) -> global___ComputeRegionUrlMapXPathMatcherXRouteRulesXUrlRedirect: ...
    def __init__(
        self,
        *,
        priority: builtins.float = ...,
        service: builtins.str = ...,
        header_action: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderAction | None = ...,
        match_rules: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRules] | None = ...,
        route_action: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteAction | None = ...,
        url_redirect: global___ComputeRegionUrlMapXPathMatcherXRouteRulesXUrlRedirect | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header_action", b"header_action", "route_action", b"route_action", "url_redirect", b"url_redirect"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_action", b"header_action", "match_rules", b"match_rules", "priority", b"priority", "route_action", b"route_action", "service", b"service", "url_redirect", b"url_redirect"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcherXRouteRules = ComputeRegionUrlMapXPathMatcherXRouteRules

@typing_extensions.final
class ComputeRegionUrlMapXPathMatcher(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_SERVICE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEFAULT_URL_REDIRECT_FIELD_NUMBER: builtins.int
    PATH_RULE_FIELD_NUMBER: builtins.int
    ROUTE_RULES_FIELD_NUMBER: builtins.int
    default_service: builtins.str
    description: builtins.str
    name: builtins.str
    @property
    def default_url_redirect(self) -> global___ComputeRegionUrlMapXPathMatcherXDefaultUrlRedirect: ...
    @property
    def path_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXPathRule]: ...
    @property
    def route_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcherXRouteRules]: ...
    def __init__(
        self,
        *,
        default_service: builtins.str = ...,
        description: builtins.str = ...,
        name: builtins.str = ...,
        default_url_redirect: global___ComputeRegionUrlMapXPathMatcherXDefaultUrlRedirect | None = ...,
        path_rule: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXPathRule] | None = ...,
        route_rules: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcherXRouteRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_url_redirect", b"default_url_redirect"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_service", b"default_service", "default_url_redirect", b"default_url_redirect", "description", b"description", "name", b"name", "path_rule", b"path_rule", "route_rules", b"route_rules"]) -> None: ...

global___ComputeRegionUrlMapXPathMatcher = ComputeRegionUrlMapXPathMatcher

@typing_extensions.final
class ComputeRegionUrlMapXTest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    description: builtins.str
    host: builtins.str
    path: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        host: builtins.str = ...,
        path: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "host", b"host", "path", b"path", "service", b"service"]) -> None: ...

global___ComputeRegionUrlMapXTest = ComputeRegionUrlMapXTest

@typing_extensions.final
class ComputeRegionUrlMapXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeRegionUrlMapXTimeouts = ComputeRegionUrlMapXTimeouts

@typing_extensions.final
class ComputeRegionUrlMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEFAULT_SERVICE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MAP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    DEFAULT_URL_REDIRECT_FIELD_NUMBER: builtins.int
    HOST_RULE_FIELD_NUMBER: builtins.int
    PATH_MATCHER_FIELD_NUMBER: builtins.int
    TEST_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    default_service: builtins.str
    description: builtins.str
    fingerprint: builtins.str
    id: builtins.str
    map_id: builtins.float
    name: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def default_url_redirect(self) -> global___ComputeRegionUrlMapXDefaultUrlRedirect: ...
    @property
    def host_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXHostRule]: ...
    @property
    def path_matcher(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXPathMatcher]: ...
    @property
    def test(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeRegionUrlMapXTest]: ...
    @property
    def timeouts(self) -> global___ComputeRegionUrlMapXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        default_service: builtins.str = ...,
        description: builtins.str = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        map_id: builtins.float = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        default_url_redirect: global___ComputeRegionUrlMapXDefaultUrlRedirect | None = ...,
        host_rule: collections.abc.Iterable[global___ComputeRegionUrlMapXHostRule] | None = ...,
        path_matcher: collections.abc.Iterable[global___ComputeRegionUrlMapXPathMatcher] | None = ...,
        test: collections.abc.Iterable[global___ComputeRegionUrlMapXTest] | None = ...,
        timeouts: global___ComputeRegionUrlMapXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_url_redirect", b"default_url_redirect", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "default_service", b"default_service", "default_url_redirect", b"default_url_redirect", "description", b"description", "fingerprint", b"fingerprint", "host_rule", b"host_rule", "id", b"id", "map_id", b"map_id", "name", b"name", "path_matcher", b"path_matcher", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "test", b"test", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRegionUrlMap = ComputeRegionUrlMap
